==> kite-1.0b6.tar.gz: kite-1.0b6/modules/__internal/_cinvoke_context.c <==
/*****************************************************************************
 * Copyright (c) 2008, Mooneer Salem
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the Kite Language organization nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY MOONEER SALEM ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL MOONEER SALEM BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ****************************************************************************/

#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include <limits.h>
#include "kite_object.h"
#include "vm/kite_vm.h"
#include "config.h"

#ifdef BUILD_CINVOKE
#include "cinvoke/cinvoke.h"

/*****************************************************************************
 * Class constructor
 ****************************************************************************/
KITE_CLASS_METHOD(CInvokeContext_construct) {
    KITE_NO_ARGS;
    (void)thd;
    this->builtin_data.filevalue = 
        (FILE*)cinv_context_create();
}

/*****************************************************************************
 * Class destructor
 ****************************************************************************/
KITE_CLASS_METHOD(CInvokeContext_destruct) {
    KITE_NO_ARGS;
    (void)thd;
    cinv_context_delete((CInvContext*)this->builtin_data.filevalue);
}

/*****************************************************************************
 * Get error message
 ****************************************************************************/
KITE_CLASS_METHOD(CInvokeContext_getError) {
    KITE_NO_ARGS;
    
    CInvContext *ctx = (CInvContext*)this->builtin_data.filevalue;
    if (cinv_context_geterrorcode(ctx))
    {
        kite_vm_return(thd, kite_new_string(thd, (char*)cinv_context_geterrormsg(ctx)));
    }
    else
    {
        kite_vm_return(thd, kite_new_null(thd));
    }
}
#endif

KITE_MODULE_INITIALIZER(_cinvoke_context) {
    /*
     * Create new class object. inherits is typically NULL for packages
     * and System.object.
     */
    kite_object_t *inherits = 
        kite_dereference_and_load(thread, "System.object");
    kite_object_t *newclass = 
        kite_new_class(thread, inherits, "_cinvoke_context");
    kite_set_docstring(newclass, "CInvokeContext internal code.");

#ifdef BUILD_CINVOKE    
    /* Add methods. */
    kite_add_method(thread, newclass, "__construct__",
        kite_new_method_with_docs(thread, FUNC_COMPILED, CInvokeContext_construct, 
                                  "Class constructor.", 0));
    kite_add_method(thread, newclass, "destruct",
        kite_new_method_with_docs(thread, FUNC_COMPILED, CInvokeContext_destruct, 
                                  "Free associated memory and resources.", 0));
    kite_add_method(thread, newclass, "get_error",
        kite_new_method_with_docs(thread, FUNC_COMPILED, CInvokeContext_getError, 
                                  "Retrieves error message from C/Invoke functions.", 0));
#endif

    /* Add to parent to complete loading. */
    kite_add_property(thread, parent, "_cinvoke_context", 1, NULL);
    kite_set_property(thread, parent, "_cinvoke_context", newclass);
}

==> kite_1.0.2.orig.tar.gz: kite-1.0.2/modules/__internal/_cinvoke_context.c <==
/*****************************************************************************
 * Copyright (c) 2008, Mooneer Salem
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the Kite Language organization nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY MOONEER SALEM ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL MOONEER SALEM BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ****************************************************************************/

#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include <limits.h>
#include "kite_object.h"
#include "vm/kite_vm.h"
#include "config.h"

#ifdef BUILD_CINVOKE
#include "cinvoke/cinvoke.h"

/*****************************************************************************
 * Class constructor
 ****************************************************************************/
KITE_CLASS_METHOD(CInvokeContext_construct) {
    KITE_NO_ARGS;
    (void)thd;
    this->builtin_data.filevalue = 
        (FILE*)cinv_context_create();
}

/*****************************************************************************
 * Class destructor
 ****************************************************************************/
KITE_CLASS_METHOD(CInvokeContext_destruct) {
    KITE_NO_ARGS;
    (void)thd;
    cinv_context_delete((CInvContext*)this->builtin_data.filevalue);
}

/*****************************************************************************
 * Get error message
 ****************************************************************************/
KITE_CLASS_METHOD(CInvokeContext_getError) {
    CInvContext *ctx = (CInvContext*)this->builtin_data.filevalue;

    KITE_NO_ARGS;
    
    if (cinv_context_geterrorcode(ctx))
    {
        kite_vm_return(thd, kite_new_string(thd, (char*)cinv_context_geterrormsg(ctx)));
    }
    else
    {
        kite_vm_return(thd, kite_new_null(thd));
    }
}
#endif

KITE_MODULE_INITIALIZER(_cinvoke_context) {
    /*
     * Create new class object. inherits is typically NULL for packages
     * and System.object.
     */
    kite_object_t *inherits = 
        kite_dereference_and_load(thread, "System.object");
    kite_object_t *newclass = 
        kite_new_class(thread, inherits, "_cinvoke_context");
    kite_set_docstring(newclass, "CInvokeContext internal code.");

#ifdef BUILD_CINVOKE    
    /* Add methods. */
    kite_add_method(thread, newclass, "__construct__",
        kite_new_method_compiled_with_docs(thread, CInvokeContext_construct, 
                                  "Class constructor.", 0));
    kite_add_method(thread, newclass, "destruct",
        kite_new_method_compiled_with_docs(thread, CInvokeContext_destruct, 
                                  "Free associated memory and resources.", 0));
    kite_add_method(thread, newclass, "get_error",
        kite_new_method_compiled_with_docs(thread, CInvokeContext_getError, 
                                  "Retrieves error message from C/Invoke functions.", 0));
#endif

    /* Add to parent to complete loading. */
    kite_add_property(thread, parent, "_cinvoke_context", 1, NULL);
    kite_set_property(thread, parent, "_cinvoke_context", newclass);
}
